client property
The client to run on; null uses the nearest QueryClientProvider's.
A different client on a later build recreates the controller; see
QueryBuilder.client.
Implementation
@override
final QueryClient? client;
The client to run on; null uses the nearest QueryClientProvider's.
A different client on a later build recreates the controller; see
QueryBuilder.client.
@override
final QueryClient? client;