value property
The current value of the object.
When the value changes, the callbacks registered with addListener will be invoked.
Implementation
@override
MutationResult<TData, TVariables> get value => _observer.currentResult;
The current value of the object.
When the value changes, the callbacks registered with addListener will be invoked.
@override
MutationResult<TData, TVariables> get value => _observer.currentResult;