refetchInterval property
Polls the query on a timer while this observer is subscribed. The default: RefetchInterval.off.
Implementation
final RefetchInterval? refetchInterval;
Polls the query on a timer while this observer is subscribed. The default: RefetchInterval.off.
final RefetchInterval? refetchInterval;