networkMode property
How connectivity gates the fetch. The default: NetworkMode.online, an offline device pauses the fetch until it is back.
Implementation
final NetworkMode? networkMode;
How connectivity gates the fetch. The default: NetworkMode.online, an offline device pauses the fetch until it is back.
final NetworkMode? networkMode;